@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: tasty-rerun
 version: 1.1.5
-id: tasty-rerun-1.1.5-b41015841efe25e60abfd67864415945
-key: tasty_HlML7uQMa2zGjsFNypo4uJ
+id: tasty-rerun-1.1.5-c3adb81e2f10ad415cdca1f1a5c11371
+key: tasty_8Y5HXCBpaf3Esc0GOnHtTx
 license: BSD3
 copyright: Oliver Charles (c) 2014
 maintainer: ollie@ocharles.org.uk
@@ -71,17 +71,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-rerun-1.1.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-rerun-1.1.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-rerun-1.1.5
-hs-libraries: HStasty-rerun-1.1.5-HlML7uQMa2zGjsFNypo4uJ
+hs-libraries: HStasty-rerun-1.1.5-8Y5HXCBpaf3Esc0GOnHtTx
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
-    reducers-3.12.1-643a8857fe1ff69e9322fcb3ed491f08
+    reducers-3.12.1-945b6d2d7be706517694521697039a82
     split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
-    tasty-0.11.0.2-6ecf5c4c4584053c63756484aea2d9b8
+    tasty-0.11.0.2-59915c063df51d2eaf213c92cd2c46a4
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
 haddock-html: /usr/share/doc/haskell-tasty-rerun/html
